@@ -263,6 +263,14 @@ class ImageRecognition(object):
                         x_batch.append(tmp_x)
                         y_pred.append(tmp_y)
 
+                        flip_tmp_x = np.flip(tmp_x, 0)
+                        x_batch.append(flip_tmp_x)
+                        y_pred.append(tmp_y)
+
+                        flip_tmp_x = np.flip(tmp_x, 1)
+                        x_batch.append(flip_tmp_x)
+                        y_pred.append(tmp_y)
+
                     except Exception as e:
                         print ("-----------------------------------------------------------------------------")
                         print ('>>> WARNING: fail handling ' +  file_list_by_class[i][idx[i]], e)
